<template>
  <div class="full-page bg">
    <div
      class="search-container"
      element-loading-text="数据加载中..."
      element-loading-spinner="el-icon-loading"
      element-loading-background="rgba(255,255,255, 0.5)"
      v-loading.fullscreen.lock="markLoading"
    >
      <el-form
        ref="form"
        :model="searchForm"
        label-width="auto"
        style="width: 100%"
      >
        <el-row :gutter="20">
          <el-col :span="5">
            <el-form-item label="区县">
              <el-input
                v-model="querys[1].value"
                clearable
                placeholder="请输入区县"
              >
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="提交审核时间">
              <el-date-picker
                v-model="querys[0].value"
                :default-time="['00:00:00', '23:59:59']"
                align="right"
                clearable
                end-placeholder="结束日期"
                placeholder="请选择提交审核日期"
                start-placeholder="开始日期"
                type="datetimerange"
                value-format="yyyy-MM-dd HH:mm:ss"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button
              icon="el-icon-search"
              type="primary"
              class="btn btn-plus"
              @click="handleSearch(1)"
            >
              搜索
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row :gutter="10" class="main-table-container flex">
      <el-col
        :span="24"
        class="table-container"
        ref="contentPanel"
        style="padding: 20px"
      >
        <div ref="btnPanel"></div>
        <div :style="{width: '100%', height: `${tableMaxHeight}` + 'px'}">
          <el-table
            stripe
            size="mini"
            v-loading="loading"
            ref="multipleSelection"
            :data="tableData"
            :max-height="tableMaxHeight"
            :style="{width: '100%'}"
          >
            <el-table-column
              type="index"
              width="60"
              label="序号"
              align="center"
            ></el-table-column>
            <el-table-column
              prop="unitName"
              width="120"
              show-overflow-tooltip
              label="区县名称"
              align="center"
            >
            </el-table-column>
            <el-table-column
              prop="eventNum"
              min-width="200"
              show-overflow-tooltip
              label="事件编号"
              align="center"
            >
            </el-table-column>
            <el-table-column
              align="center"
              label="提交审核时间"
              sortable
              prop="operateDate"
              show-overflow-tooltip
            >
            </el-table-column>
            <el-table-column
              show-overflow-tooltip
              label="审核状态"
              align="center"
            >
              <template v-slot="{row}">
                <el-tag
                  :type="
                    !row.status
                      ? 'info'
                      : row.status === 1 || row.status === 3
                      ? ''
                      : row.status === 2 || row.status === 4
                      ? 'danger'
                      : row.status === 5
                      ? 'success'
                      : ''
                  "
                >
                  {{ getDictName('xjggqk_shzt', row.status) }}
                </el-tag>
              </template>
            </el-table-column>
            <el-table-column
              show-overflow-tooltip
              align="center"
              fixed="right"
              width="200"
              label="操作"
            >
              <template v-slot="{row}">
                <el-link
                  v-if="row.status === 3"
                  icon="el-icon-refresh"
                  type="primary"
                  :underline="false"
                  class="cloumn-btn"
                  @click="handleDbClick(row, '改革办审核')"
                >
                  审核
                </el-link>
                <el-link
                  icon="el-icon-edit"
                  v-if="row.status === 4 || row.status === 5"
                  type="primary"
                  :underline="false"
                  class="cloumn-btn"
                  @click="handleDbClick(row, '编辑')"
                >
                  编辑
                </el-link>
                <el-link
                  icon="el-icon-view"
                  type="primary"
                  :underline="false"
                  class="cloumn-btn"
                  @click="handleDbClick(row, '详情')"
                >
                  详情
                </el-link>
<!--                <el-link-->
<!--                  icon="el-icon-paperclip"-->
<!--                  type="primary"-->
<!--                  :underline="false"-->
<!--                  class="cloumn-btn"-->
<!--                  @click="historicalDismissal(row)"-->
<!--                >-->
<!--                  历史驳回-->
<!--                </el-link>-->
              </template>
            </el-table-column>
          </el-table>
        </div>
        <pagination
          ref="paginationPanel"
          style="margin-top: 10px"
          :pageResult="queryParam.pageBean"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
        />
      </el-col>
    </el-row>
    <add-form-dialog ref="addFormDialog" @confirm="onConfirm"></add-form-dialog>
    <refusal-dialog ref="refusalDialog"></refusal-dialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import utils from '@/utils.js'
import pagination from '@/components/pagination/index.vue'
import AddFormDialog from '@/views/ReformSituation/components/addFormDialog.vue'
import countyApi from '@/api/ReformSituation/countyApi'
import RefusalDialog from '@/views/ReformSituation/components/refusalDialog.vue'

export default {
  name: 'qxReformSituationPropel',
  components: {
    RefusalDialog,
    AddFormDialog,
    pagination
  },
  mixins: [TableMixin],
  data() {
    return {
      markLoading: false,
      searchForm: {},
      loading: false,
      tableData: [],
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'OPERATE_DATE_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'unit_name_',
          relation: 'AND',
          value: ''
        },
      ],
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0
        },
        params: {
          level: '3'
        }
      },
      // 弹层
      addDialogShow: false,
      addRow: {},
      addTitle: ''
    }
  },
  created() {
    this.getData()
  },
  methods: {
    historicalDismissal(data){
      this.$refs.refusalDialog.upDate(data)
    },
    handleSearch(page) {
      this.queryParam.querys = []
      this.querys.forEach(item => {
        if (item.value !== undefined) {
          this.queryParam.querys.push(item)
        }
      })
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.getData()
    },
    getData() {
      this.loading = true
      this.tableData = []
      this.queryParam.querys = this.querys
      countyApi.checkAndApproveData(this.queryParam).then(res => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParam.pageBean.page = res.page
          this.queryParam.pageBean.total = res.total
          this.$set(this.tableData)
          this.loading = false
        }
      })
    },
    handleDbClick(data, title) {
      this.$refs.addFormDialog.upDate(data, title)
    },
    // 撤回
    revocation(item) {
      // let data = {
      //   status: 0,
      //   id: item.recId
      // }
      this.$confirm('确认执行撤销操作吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'error'
      }).then(() => {
        this.markLoading = true
        // data.approvalResults = 2
        // pilot.updateMunStatus(data, res => {
        //   if (res.state) {
        //     this.$message.success('撤销操作成功')
        //     this.handleSearch(1)
        //   }
        //   this.markLoading = false
        // })
      })
    },
    //展示数量
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.handleSearch(1)
    },
    //表格页数
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.handleSearch(val)
    },
    onConfirm() {
      this.handleSearch(1)
    }
  }
}
</script>

<style lang="scss" scoped>
.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }
  &:nth-child(2) {
    margin-right: 5px;
  }
  &:nth-child(3) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  &:nth-child(3):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  &:nth-child(4):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  /deep/ i,
  span {
    font-size: 14px;
  }
}
</style>